%{
/*
 * Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

#include <opensm/osm_file_ids.h>
#define FILE_ID OSM_FILE_FABRIC_MODE_PARSER_L_L
#include "osm_fabric_mode_parser_y.h"

extern char *__fabric_mode_parser_yylval;
extern char *trim_whitespace(char *str);
#define SAVE_POS save_pos()
static void save_pos();

extern int fabric_mode_column_num;
extern int fabric_mode_line_num;
%}

%option nounput noinput noyywrap
STRING [a-zA-Z0-9'_''\-''|''&''@''('')''/''#''!''?''+''=''[''\]''\/''{''}'';''%''*''^''\\'':']*

%%

\#.*\n			{ SAVE_POS; return COMMENT; }
[ \t]*\n		{ SAVE_POS; } /* ignore end of line and empty lines*/
[' ']*			{ SAVE_POS; } /* ignore spaces */
,			{ SAVE_POS; return COMMA; }
true			{ SAVE_POS; return TK_TRUE; }
false			{ SAVE_POS; return TK_FALSE; }

[ \t]*profile\_start[ \t]*		{ SAVE_POS; return PROFILE_START; }
[ \t]*profile\_end[ \t]*		{ SAVE_POS; return PROFILE_END; }

[ \t]*profile\_name:[ \t]*		{ SAVE_POS; return PROFILE_NAME; }

[ \t]*bw\_utilization:[ \t]*		{ SAVE_POS; return BW_UTILIZATION; }

[ \t]*turbo\_path\_enable:[ \t]*	{ SAVE_POS; return TP_ENABLE; }
[ \t]*disable[ \t]*			{ SAVE_POS; return DISABLE; }
[ \t]*device\_defaults[ \t]*		{ SAVE_POS; return DEVICE_DEFAULTS; }
[ \t]*custom[ \t]*			{ SAVE_POS; return CUSTOM; }
[ \t]*no\_change[ \t]*			{ SAVE_POS; return NO_CHANGE; }

[ \t]*tp\_req\_delay:[ \t]*		{ SAVE_POS; return TP_REQ_DELAY; }
[ \t]*tp\_set\_trig\_th:[ \t]*		{ SAVE_POS; return TP_SET_TRIG_TH; }
[ \t]*tp\_rst\_trig\_th:[ \t]*		{ SAVE_POS; return TP_RST_TRIG_TH; }
[ \t]*tp\_req\_trig\_window:[ \t]*	{ SAVE_POS; return TP_REQ_TRIG_WINDOW; }

0[xX][0-9a-fA-F]+	{
				SAVE_POS;
				__fabric_mode_parser_yylval = strdup(yytext);
				return NUMBER;
			}

[0-9]+[^\.]		{
				SAVE_POS;
				free(__fabric_mode_parser_yylval);
				__fabric_mode_parser_yylval = strdup(yytext);
				return NUMBER;
			}

{STRING}		{
				free(__fabric_mode_parser_yylval);
				__fabric_mode_parser_yylval = strdup(trim_whitespace(yytext));
				SAVE_POS;
				return TEXT;
			}

.			{	return ERROR;	}
%%

static void save_pos()
{
	int i;
	for (i = 0; i < yyleng; i++) {
		if (yytext[i] == '\n') {
			fabric_mode_line_num++;
			fabric_mode_column_num = 1;
		} else {
			fabric_mode_column_num++;
		}
	}
}
